<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/compresseur.git

return [

	// C
	'compresseur_description' => 'Compression des css et javascript dans l’en-tête des pages html de <code>ecrire/</code> et/ou du site public',
	'compresseur_slogan' => 'Compression des css et javascript',
];
